@@ -7,7 +7,7 @@ import pytest
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
-class DnsParkProviderTests(TestCase, IntegrationTests):
+class CloudXNSProviderTests(TestCase, IntegrationTests):
 
     Provider = Provider
     provider_name = 'cloudxns'
@@ -15,7 +15,7 @@ class DnsParkProviderTests(TestCase, IntegrationTests):
     def _filter_post_data_parameters(self):
         return ['login_token']
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="regenerating auth keys required")
+    # TODO: the following skipped suite and fixtures should be enabled
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
\ No newline at end of file
