@@ -19,7 +19,6 @@ class DigitalOceanProviderTests(TestCase, IntegrationTests):
     def test_Provider_when_calling_list_records_after_setting_ttl(self):
         return
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="regenerating auth keys required")
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
\ No newline at end of file
