@@ -15,12 +15,13 @@ class DnsParkProviderTests(TestCase, IntegrationTests):
     def _filter_headers(self):
         return ['Authorization']
 
-    @pytest.mark.skip(reason="domain no longer exists")
-    def test_Provider_when_calling_list_records_after_setting_ttl(self):
+    # TODO: the following skipped suite and fixtures should be enabled
+    @pytest.mark.skip(reason="new test, missing recording")
+    def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
 
-    @pytest.mark.skip(reason="regenerating auth keys required")
-    def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
+    @pytest.mark.skip(reason="new test, missing recording")
+    def test_Provider_when_calling_list_records_after_setting_ttl(self):
         return
 
     @pytest.fixture(autouse=True)
