@@ -24,12 +24,11 @@ class EasyDnsProviderTests(TestCase, IntegrationTests):
     def _filter_query_parameters(self):
         return ['_key', '_user']
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="regenerating auth keys required")
+    # TODO: the following skipped suite and fixtures should be enabled
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
 
-
     @pytest.fixture(autouse=True)
     def skip_suite(self, request):
         if request.node.get_marker('ext_suite_1'):
