@@ -21,7 +21,7 @@ class NameSiloProviderTests(TestCase, IntegrationTests):
     def _filter_query_parameters(self):
         return ['key']
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="regenerating auth keys required")
+    # TODO: the following skipped suite and fixtures should be enabled
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
\ No newline at end of file
