@@ -11,7 +11,7 @@ class OvhProviderTests(TestCase, IntegrationTests):
 
     Provider = Provider
     provider_name = 'ovh'
-    domain = 'elogium.net'
+    domain = 'pacalis.net'
 
     def _filter_headers(self):
         return ['X-Ovh-Application', 'X-Ovh-Consumer', 'X-Ovh-Signature']
@@ -20,10 +20,4 @@ class OvhProviderTests(TestCase, IntegrationTests):
     def _test_options(self):
         cmd_options = super(OvhProviderTests, self)._test_options()
         cmd_options.update({'auth_entrypoint':'ovh-eu'})
-        return cmd_options
-
-    # TODO: the following skipped suite and fixtures should be enabled
-    @pytest.fixture(autouse=True)
-    def skip_suite(self, request):
-        if request.node.get_marker('ext_suite_1'):
-            pytest.skip('Skipping extended suite')
\ No newline at end of file
+        return cmd_options
\ No newline at end of file
