@@ -1,10 +1,13 @@
 """"Test for rackspace implementation of the lexicon interface"""
 from unittest import TestCase
 import pytest
+import logging
 
 from lexicon.providers.rackspace import Provider
 from integration_tests import IntegrationTests
 
+logger = logging.getLogger(__name__)
+
 # Hook into testing framework by inheriting unittest.TestCase and reuse
 # the tests which *each and every* implementation of the interface must
 # pass, by inheritance from define_tests.TheTests
@@ -27,16 +30,17 @@ class RackspaceProviderTests(TestCase, IntegrationTests):
     # regenerate the fixtures
     def _test_options(self):
         options = super(RackspaceProviderTests, self)._test_options()
+        # Set this to 1 if you are making new recordings and set to 0 when
+        # finished to make sure we don't actually sleep and waste time
+        # when we are replaying. Rackspace API calls are async, so you place
+        # the initial request and then make update calls to see if the action
+        # is complete and has a response.
         options.update({
-            # 'auth_account': '123456',
-            # 'auth_username': 'foo',
-            # 'auth_api_key': 'bar',
-            'sleep_time': '0'
+            'sleep_time': '0',
         })
-        options['auth_token'] = None
         return options
 
-    @pytest.fixture(autouse=True)
-    def skip_suite(self, request):
-        if request.node.get_marker('ext_suite_1'):
-            pytest.skip('Skipping extended suite')
\ No newline at end of file
+    def _test_engine_overrides(self):
+        overrides = super(RackspaceProviderTests, self)._test_engine_overrides()
+        overrides['fallbackFn'] = (lambda x: 'placeholder_' + x if x != 'auth_token' else None)
+        return overrides
