@@ -20,8 +20,9 @@ class ZonomiProviderTests(TestCase, IntegrationTests):
     def _filter_query_parameters(self):
         return ['api_key']
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="The record identifier is based on the name, this needs disabled")
+
+    # TODO: the following skipped suite and fixtures should be enabled
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
 
